@@ -1,6 +1,6 @@
 // 2003-05-01 Petur Runolfsson <peturr02@ru.is>
 
-// Copyright (C) 2003-2024 Free Software Foundation, Inc.
+// Copyright (C) 2003-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -18,12 +18,13 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-require-fileio "" }
+// { dg-additional-files "cin_unget-1.txt" }
 
 #include <ext/stdio_sync_filebuf.h>
 #include <testsuite_hooks.h>
 
 // libstdc++/12048
-void test05()
+void test04()
 {
   const char* name = "cin_unget-1.txt";
 
@@ -33,7 +34,7 @@ void test05()
   VERIFY( sbuf.sgetn(buf, 2) == 2 );
   int c2 = sbuf.sungetc();
   VERIFY( c2 != EOF );
-  int c3 = std::fgetc(file);
+  int c3 = sbuf.sbumpc();
   VERIFY( c3 == std::char_traits<char>::to_int_type(buf[1]) );
 
   std::fclose(file);
@@ -41,6 +42,6 @@ void test05()
 
 int main ()
 {
-  test05();
+  test04();
   return 0;
 }
